## Summary

<!-- What does this PR do? Keep it to 1-3 sentences. -->

## Changes

<!-- Bulleted list of key changes. -->

-

## Related Issues

<!-- Link related issues: Fixes #123, Closes #456 -->

## Checklist

- [ ] `poe all` passes (lint + typecheck + test)
- [ ] Tests added/updated for new functionality
- [ ] No hardcoded secrets or sensitive data
